﻿using System;
using Xamarin.Forms;
using SampleProject.Droid;
using Xamarin.Forms.Platform.Android;
using System.ComponentModel;
using Android.Graphics;
using SampleProject;

[assembly: ExportRenderer(typeof(DrawRect), typeof(RectRenderer))]
namespace SampleProject.Droid {
	public class RectRenderer : VisualElementRenderer<DrawRect> {
		private DrawRect drawSender;

		public RectRenderer() {
			this.SetWillNotDraw(false);
		}

		protected override void OnElementPropertyChanged(object sender, PropertyChangedEventArgs e) {
			base.OnElementPropertyChanged(sender, e);

			//Tried it with DrawRect.ColorProperty.PropertyName and it does not get called either, nor any property.
			if (e.PropertyName == DrawRect.WidthProperty.PropertyName)
				this.Invalidate(); // Force a call to OnDraw. This does in fact get called.
			
			drawSender = ((DrawRect)sender);
		}

		//Does not get fired off, despite Invalidate getting called.
		protected override void OnDraw(Canvas canvas) {
			base.OnDraw (canvas);
			var element = this.Element;
			var rect = new Rect();
			this.GetDrawingRect(rect);
			var paint = new Paint() {
				Color = element.Color.ToAndroid(),
				AntiAlias = true,
				StrokeWidth = drawSender.StrokeWidth,
				Alpha = (int)drawSender.Opacity
			};

			if (!drawSender.Fill)
				paint.SetStyle(Paint.Style.Stroke);

			canvas.DrawRect(new RectF(rect), paint);
		}
	}
}

